****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_time.sas 
*
* Created (mm/dd/yyyy): 07/31/2014
* Last modified: mm/dd/yyyys
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*  This program is composed of two macros: ms_starttimer and ms_stoptimer;
*
*
* PARAMETERS:
*
*  ms_starttimer(START=)
*      START=Name of the macro variable that will hold the time.
*      Example: %ms_starttimer(START=MAINSTART)
*  
*  ms_stoptimer(START=)
*      Parm1=Reference to the name of the macro variable that will hold the time.
*      Example: %ms_stoptimer(START=&MAINSTART.)   *Notice the  use of & and .
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials	   Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*             mm/dd/yy
*
***************************************************************************************************;


%macro ms_starttimer(START=);

%put =====> MACRO CALLED: ms_starttimer v1.0;

%global &START.;
/*Set macro variables for Query dates*/
data _NULL_;
   temp=DATETIME();
   call symputx("&START.",temp);
   call symputx("STARTDATE",put(datepart(temp),date9.));
   call symputx("STARTTIME",put(timepart(temp),time4.));
run;

%put &MAINSTART.;

%put NOTE: ********END OF MACRO: ms_starttimer v1.0********;

%mend;

%macro ms_stoptimer(start=);

%put =====> MACRO CALLED: ms_stoptimer v1.0;

%put "&start.";

%global STOP;
%global hours;
%global minutes;
%global seconds;
%global totalseconds;

data _NULL_;
   temp=DATETIME();
   seconds=temp-&start.;
   hours=int(seconds/3600);
   minutes=int((seconds-hours*3600)/60);
   seconds2=int((seconds-hours*3600-minutes*60));
   call symput("STOP",put(temp,best.));
   call symput("hours",put(hours,4.0));
   call symput("minutes",put(minutes,2.0));
   call symput("seconds",put(seconds2,2.0));
run;

%PUT TOTAL RUN TIME was &hours. h &minutes. m &seconds. s; 

%put NOTE: ********END OF MACRO: ms_stoptimer v1.0********;

%mend;

%macro create_signature;


%put =====> MACRO CALLED: create_signature ;

data msoc.ms_time_signature;
  DPID="&DPID";
  SITEID="&SITEID";
  DP_MinDate=&DP_MinDate;
  DP_MaxDate=&DP_MaxDate;
  ETL=&ETL;
  MSReqID="&MSReqID";
  MSProjID="&MSProjID";
  MSWPType="&MSWPType";
  MSWPID="&MSWPID";
  MSDPID="&MSDPID";
  MSVerID="&MSVerID";
  Program_name="&prg_name_sh1";
  Starttime=input("&MainStart.", best.);
  StopTime=input("&Stop.", best.);
  Seconds=put(int(&stop.-&MainStart.), best.)||" s";
  Executiontime="&hours.h &minutes.m &seconds. s";

format dp_mindate dp_maxdate mmddyy10. Seconds $20. StartTime Stoptime datetime21.2;
run;

%put NOTE: ********END OF MACRO: create_signature ********;

proc print data=msoc.ms_time_signature;
 run;

%mend;
